==> zego_express_engine-2.21.2.tar.gz: ios/Classes/internal/ZegoTextureRendererController.h <==
//
//  ZegoTextureRendererController.h
//  Pods
//
//  Created by lizhanpeng@ZEGO on 2020/3/26.
//  Copyright © 2020 Zego. All rights reserved.
//

#ifndef ZegoTextureRenderController_h
#define ZegoTextureRenderController_h

#import "ZegoTextureRenderer.h"
#import <Foundation/Foundation.h>
#import <ZegoExpressEngine/ZegoExpressEngine.h>

NS_ASSUME_NONNULL_BEGIN

@interface ZegoTextureRendererController : NSObject <ZegoCustomVideoRenderHandler>

@property (nonatomic, assign) BOOL isUseFrontCam;

+ (instancetype)sharedInstance;

#pragma mark - Dart Texture Render Utils Operation

/// Called when dart invoke `createTextureRenderer`
/// @return textureID
- (int64_t)createTextureRenderer:(id<FlutterTextureRegistry>)registry
                       viewWidth:(int)width
                      viewHeight:(int)height;

/// Called when dart invoke `updateTextureRendererSize`
- (BOOL)updateTextureRenderer:(int64_t)textureID viewWidth:(int)width viewHeight:(int)height;

/// Called when dart invoke `destroyTextureRenderer`
- (BOOL)destroyTextureRenderer:(int64_t)textureID;

#pragma mark - Dart Express Engine API Operation

/// Called when dart invoke `createEngine`
- (void)initController;

/// Called when dart invoke `destroyEngine`
- (void)uninitController;

/// Called when dart invoke `startPreview`
- (BOOL)addCapturedRenderer:(int64_t)textureID
                        key:(NSNumber *)channel
                   viewMode:(ZegoViewMode)viewMode;

/// Called when dart invoke `stopPreview`
- (void)removeCapturedRenderer:(NSNumber *)channel;

/// Called when dart invoke `startPlayingStream`
- (BOOL)addRemoteRenderer:(int64_t)textureID
                      key:(NSString *)streamID
                 viewMode:(ZegoViewMode)viewMode;

/// Called when dart invoke `stopPlayingStream`
- (void)removeRemoteRenderer:(NSString *)streamID;

/// For video preview/play
- (void)startRendering;

/// For video preview/play
- (void)stopRendering;

- (void)onCapturedVideoFrameCVPixelBuffer:(CVPixelBufferRef)buffer
                                    param:(ZegoVideoFrameParam *)param
                                 flipMode:(ZegoVideoFlipMode)flipMode
                                  channel:(ZegoPublishChannel)channel;

@end

NS_ASSUME_NONNULL_END

#endif /* ZegoTextureRenderController_h */

==> zego_express_engine-3.1.0.tar.gz: ios/Classes/internal/ZegoTextureRendererController.h <==
//
//  ZegoTextureRendererController.h
//  Pods
//
//  Created by lizhanpeng@ZEGO on 2020/3/26.
//  Copyright © 2020 Zego. All rights reserved.
//

#ifndef ZegoTextureRenderController_h
#define ZegoTextureRenderController_h

#import "ZegoTextureRenderer.h"
#import <Foundation/Foundation.h>
#import <ZegoExpressEngine/ZegoExpressEngine.h>

NS_ASSUME_NONNULL_BEGIN

@interface ZegoTextureRendererController : NSObject <ZegoCustomVideoRenderHandler, ZegoMediaPlayerVideoHandler>

+ (instancetype)sharedInstance;

#pragma mark - Dart Texture Render Utils Operation

/// Called when dart invoke `createTextureRenderer`
/// @return textureID
- (int64_t)createTextureRenderer:(id<FlutterTextureRegistry>)registry
                       viewWidth:(int)width
                      viewHeight:(int)height;

/// Called when dart invoke `destroyTextureRenderer`
- (BOOL)destroyTextureRenderer:(int64_t)textureID;

#pragma mark - Dart Express Engine API Operation

/// Called when dart invoke `createEngine`
- (void)initControllerWithMessenger:(NSObject<FlutterBinaryMessenger> *)messenger;

/// Called when dart invoke `destroyEngine`
- (void)uninitController;

/// Called when dart invoke `startPreview`
- (BOOL)bindCapturedChannel:(NSNumber *)channel withTexture:(int64_t)textureID;

/// Called when dart invoke `stopPreview`
- (void)unbindCapturedChannel:(NSNumber *)channel;

/// Called when dart invoke `startPlayingStream`
- (BOOL)bindRemoteStreamId:(NSString *)streamId withTexture:(int64_t)textureID;

/// Called when dart invoke `stopPlayingStream`
- (void)unbindRemoteStreamId:(NSString *)streamId;

/// Called when dart invoke `mediaPlayerSetPlayerCanvas`
- (BOOL)bindMediaPlayerIndex:(NSNumber *)index withTexture:(int64_t)textureID;

/// Called when dart invoke `destroyMediaPlayer`
- (void)unbindMediaPlayerIndex:(NSNumber *)index;

#pragma mark - For CustomVideoCaptureManager
- (void)onCapturedVideoFrameCVPixelBuffer:(CVPixelBufferRef)buffer
                                    param:(ZegoVideoFrameParam *)param
                                 flipMode:(ZegoVideoFlipMode)flipMode
                                  channel:(ZegoPublishChannel)channel;

@end

NS_ASSUME_NONNULL_END

#endif /* ZegoTextureRenderController_h */
